==> rdf4j-spin-4.2.3-sources.jar: org/eclipse/rdf4j/spin/function/apf/ConcatTupleFunction.java <==
/*******************************************************************************
 * Copyright (c) 2015 Eclipse RDF4J contributors, Aduna, and others.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Distribution License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 *******************************************************************************/
package org.eclipse.rdf4j.spin.function.apf;

import java.util.Collections;
import java.util.List;

import org.eclipse.rdf4j.common.iteration.CloseableIteration;
import org.eclipse.rdf4j.common.iteration.SingletonIteration;
import org.eclipse.rdf4j.model.Literal;
import org.eclipse.rdf4j.model.Value;
import org.eclipse.rdf4j.model.ValueFactory;
import org.eclipse.rdf4j.model.vocabulary.APF;
import org.eclipse.rdf4j.query.QueryEvaluationException;
import org.eclipse.rdf4j.query.algebra.evaluation.function.string.Concat;
import org.eclipse.rdf4j.spin.function.InverseMagicProperty;

public class ConcatTupleFunction implements InverseMagicProperty {

	@Override
	public String getURI() {
		return APF.CONCAT.toString();
	}

	@Override
	public CloseableIteration<? extends List<? extends Value>, QueryEvaluationException> evaluate(
			ValueFactory valueFactory, Value... args) throws QueryEvaluationException {
		Literal result = new Concat().evaluate(valueFactory, args);
		return new SingletonIteration<List<? extends Value>, QueryEvaluationException>(
				Collections.singletonList(result));
	}
}

==> rdf4j-spin-5.0.2-sources.jar: org/eclipse/rdf4j/spin/function/apf/ConcatTupleFunction.java <==
/*******************************************************************************
 * Copyright (c) 2015 Eclipse RDF4J contributors, Aduna, and others.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Distribution License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 *******************************************************************************/
package org.eclipse.rdf4j.spin.function.apf;

import java.util.Collections;
import java.util.List;

import org.eclipse.rdf4j.common.iteration.CloseableIteration;
import org.eclipse.rdf4j.common.iteration.SingletonIteration;
import org.eclipse.rdf4j.model.Literal;
import org.eclipse.rdf4j.model.Value;
import org.eclipse.rdf4j.model.ValueFactory;
import org.eclipse.rdf4j.model.vocabulary.APF;
import org.eclipse.rdf4j.query.QueryEvaluationException;
import org.eclipse.rdf4j.query.algebra.evaluation.function.string.Concat;
import org.eclipse.rdf4j.spin.function.InverseMagicProperty;

public class ConcatTupleFunction implements InverseMagicProperty {

	@Override
	public String getURI() {
		return APF.CONCAT.toString();
	}

	@Override
	public CloseableIteration<? extends List<? extends Value>> evaluate(
			ValueFactory valueFactory, Value... args) throws QueryEvaluationException {
		Literal result = new Concat().evaluate(valueFactory, args);
		return new SingletonIteration<List<? extends Value>>(
				Collections.singletonList(result));
	}
}
